/** @file chessboard.c
* PURPOSE: file creates a visual chessbord on screen
* 
* @author Daniel Hasemann
* @version 1.0
* @date December 16th, 2005
*************************************************/

#include "ndame.h"

/** @brief chessboard
*  
*This function prints a chessboard on screen, which can change the size
*between MAX_SIZE x MAX_SIZE and MIN_SIZE x MIN_SIZE. There is a frame
*around the chessboard with a variable size. To identify every flied on
*the chessboard there are number and letter combinations from A1
*(left lower position) to L12 (right upper position) around the board.
*@param *d1 is a struct pointer
*@see menu()
*@see options()
*@author Daniel Hasemann
*@date December 16th, 2005
***************************************/

void chessboard(struct data*d1)
{
    int ii;
    int ik;
    int iletter=65;
    int inumber=d1->iblength;
    
    textcolor(C_CHESSBOARD);
    
    for (ii=0;ii<d1->iblength;ii++)                   //print chessboard
    {
        for (ik=0;ik<d1->iblength;ik++)
        {
            if((ii+ik)%2)
            {
                gotoxy(ii+X_POS,ik+Y_POS);   
                printf("%c",BOARD_PART_1);               
            }
            else
            {
                gotoxy(ii+X_POS,ik+Y_POS);   
                printf("%c",BOARD_PART_2);
            }       
        }
    }
    for (ik=0;ik<d1->iblength;ik++)                   //print frame around chessboard
    {   
        gotoxy(ik+X_POS,Y_POS-1);
        printf("%c",205);                             //horizontal upper frame
        
        gotoxy(X_POS-1,Y_POS+ik);
        printf("%c",186);                             //vertical left frame
        
        gotoxy(ik+X_POS,Y_POS+d1->iblength);
        printf("%c",205);                             //horizontal lower frame
        
        gotoxy(d1->iblength+X_POS,Y_POS+ik);
        printf("%c",186);                             //vertical right frame
    
        gotoxy(ik+X_POS,Y_POS+d1->iblength+1);        //Letters
        printf("%c",iletter);
        
        gotoxy(X_POS+d1->iblength+1,Y_POS+ik);
        printf("%d",inumber);                         //Numbers
        
        iletter++;
        inumber--;
    }        
    gotoxy(X_POS-1,Y_POS-1);
    printf("%c",201);                                 //frame corner left upper
    gotoxy(X_POS+d1->iblength,Y_POS-1);               
    printf("%c",187);                                 //frame corner right upper
    gotoxy(X_POS-1,Y_POS+d1->iblength);
    printf("%c",200);                                 //frame corner left lower
    gotoxy(X_POS+d1->iblength,Y_POS+d1->iblength);
    printf("%c",188);                                 //frame corner right lower
}
